@@ -32,21 +32,20 @@ use Pod::Text;
 $parser = Pod::Text->new(loose=>1);
 $parser->parse_from_file('mk-src.pod', 'mk-src.txt');
 
+#use Pod::LaTeX;
+#$parser = Pod::LaTeX->new(AddPreamble => 0, AddPostamble => 0);
+#$parser->parse_from_file('mk-src.pod', '../manual/mk-src.tex.new');
 
-use Pod::LaTeX;
-$parser = Pod::LaTeX->new(AddPreamble => 0, AddPostamble => 0);
-$parser->parse_from_file('mk-src.pod', '../manual/mk-src.tex.new');
-
-$/ = undef;
-open IN, '../manual/mk-src.tex';
-$orig = <IN>;
-open IN, '../manual/mk-src.tex.new';
-$new = <IN>;
-close IN;
-if ($orig eq $new) {
-  print "mk-src.tex unchanged\n";
-} else {
-  rename '../manual/mk-src.tex.new', '../manual/mk-src.tex';
-}
+#$/ = undef;
+#open IN, '../manual/mk-src.tex';
+#$orig = <IN>;
+#open IN, '../manual/mk-src.tex.new';
+#$new = <IN>;
+#close IN;
+#if ($orig eq $new) {
+#  print "mk-src.tex unchanged\n";
+#} else {
+#  rename '../manual/mk-src.tex.new', '../manual/mk-src.tex';
+#}
 
 #unlink "mk-src.pod";
