@@ -8,6 +8,7 @@
 //#define DEBUG {fprintf(stderr,"File: %s(%i)\n",__FILE__,__LINE__);}
 #include <string.h>
 #include <stdlib.h>
+#include "ndebug.hpp"
 #include <assert.h>
 
 #include "dirs.h"
@@ -1386,7 +1387,7 @@ namespace acommon {
        /* TRANSLATORS: It is OK if this is longer than 50 chars */
        N_("ignore accents when checking words -- CURRENTLY IGNORED"), KEYINFO_MAY_CHANGE | KEYINFO_HIDDEN}
     , {"ignore-case", KeyInfoBool  , "false",
-       N_("ignore case when checking words"), KEYINFO_MAY_CHANGE | KEYINFO_HIDDEN}
+       N_("ignore case when checking words"), KEYINFO_MAY_CHANGE}
     , {"ignore-repl", KeyInfoBool  , "false",
        N_("ignore commands to store replacement pairs"), KEYINFO_MAY_CHANGE}
     , {"jargon",     KeyInfoString, "",
@@ -1521,3 +1522,4 @@ namespace acommon {
   }
   
 }
+
