@@ -8,7 +8,6 @@
 #define ASPELL_FSTREAM__HPP
 
 #include <stdio.h>
-#include <stdarg.h>
 
 #include "string.hpp"
 #include "istream.hpp"
@@ -34,7 +33,7 @@ namespace acommon {
       : IStream('\n'), file_(f), own_(own) {}
     ~FStream() {close();}
 
-    PosibErr<void> open(ParmString, const char *);
+    PosibErr<void> open(ParmStr, const char *);
     void close();
  
     operator bool() {return file_ != 0 && !feof(file_) && !ferror(file_);}
@@ -46,24 +45,9 @@ namespace acommon {
     FILE * c_stream();
     int file_no();
     
-    __attribute__ ((format (printf,2,3)))
-      int print(const char * format, ...)
+    int vprintf(const char * format, va_list ap)
     {
-      va_list ap;
-      va_start(ap, format);
-      int res = vfprintf(file_, format, ap);
-      va_end(ap);
-      return res;
-    }
-
-    __attribute__ ((format (scanf,2,3)))
-      int scan(const char * format, ...)
-    {
-      va_list ap;
-      va_start(ap, format);
-      int res = vfscanf(file_, format, ap);
-      va_end(ap);
-      return res;
+      return vfprintf(file_, format, ap);
     }
 
     void flush() {fflush(file_);}
@@ -74,15 +58,11 @@ namespace acommon {
     void skipws();
 
     // Will return false if there is no more data
-    bool getline(String & str) {return IStream::getline(str);}
-    bool getline(String &, char d);
+    bool append_line(String &, char d);
 
-    char * getline(char * str, size_t s) {return IStream::getline(str,s);}
-    char * getline(char *, size_t, char d);
-
-    // These perform raw io with any sort of formating
+    // These perform raw io with any sort of formatting
     bool read(void *, unsigned int i);
-    void write(ParmString);
+    void write(ParmStr);
     void write(char c);
     void write(const void *, unsigned int i);
 
@@ -110,7 +90,7 @@ namespace acommon {
     FStream & operator>> (String &);
     FStream & operator>> (unsigned int &);
     FStream & operator>> (int &);
-    FStream & operator<< (ParmString);
+    FStream & operator<< (ParmStr);
     FStream & operator<< (unsigned int);
     FStream & operator<< (int);
     FStream & operator<< (double);
