@@ -193,7 +193,7 @@ struct CondsLookupParms {
   typedef const Conds * Value;
   typedef const char * Key;
   static const bool is_multi = false;
-  hash<const char *> hfun;
+  acommon::hash<const char *> hfun;
   size_t hash(const char * s) {return hfun(s);}
   bool equal(const char * x, const char * y) {return strcmp(x,y) == 0;}
   const char * key(const Conds * c) {return c->str;}
@@ -202,7 +202,7 @@ struct CondsLookupParms {
 typedef HashTable<CondsLookupParms> CondsLookup;
 
 // normalizes and checks the cond_str
-// returns the lenth of the new string or -1 if invalid
+// returns the length of the new string or -1 if invalid
 static int normalize_cond_str(char * str)
 {
   char * s = str;
@@ -452,7 +452,7 @@ PosibErr<void> AffixMgr::parse_file(const char * affpath, Conv & iconv)
   // prefix is not found (call it nextne).
 
   // Since we have built ordered lists, all that remains is to
-  // properly intialize the nextne and nexteq pointers that relate
+  // properly initialize the nextne and nexteq pointers that relate
   // them
 
   process_pfx_order();
@@ -840,7 +840,16 @@ bool AffixMgr::affix_check(const LookupInfo & linf, ParmString word,
   if (prefix_check(linf, pword, ci, gi)) return true;
 
   // if still not found check all suffixes
-  return suffix_check(linf, sword, ci, gi, 0, NULL);
+  if (suffix_check(linf, sword, ci, gi, 0, NULL)) return true;
+
+  // if still not found check again but with the lower case version
+  // which can make a difference if the entire word matches the cond
+  // string
+  if (cp == FirstUpper) {
+    return suffix_check(linf, pword, ci, gi, 0, NULL);
+  } else {
+    return false;
+  }
 }
 
 void AffixMgr::munch(ParmString word, GuessInfo * gi, bool cross) const
@@ -1057,7 +1066,7 @@ bool PfxEntry::check(const LookupInfo & linf, const AffixMgr * pmyMgr,
   unsigned              tmpl;   // length of tmpword
   WordEntry             wordinfo;     // hash entry of root word or NULL
   byte *	cp;		
-  VARARRAYM(char, tmpword, word.size()+1, MAXWORDLEN+1);
+  VARARRAYM(char, tmpword, word.size()+stripl+1, MAXWORDLEN+1);
 
   // on entry prefix is 0 length or already matches the beginning of the word.
   // So if the remaining root word has positive length
@@ -1204,7 +1213,7 @@ bool SfxEntry::check(const LookupInfo & linf, ParmString word,
   int			cond;		 // condition beng examined
   WordEntry             wordinfo;        // hash entry pointer
   byte *	cp;
-  VARARRAYM(char, tmpword, word.size()+1, MAXWORDLEN+1);
+  VARARRAYM(char, tmpword, word.size()+stripl+1, MAXWORDLEN+1);
   PfxEntry* ep = (PfxEntry *) ppfx;
 
   // if this suffix is being cross checked with a prefix
@@ -1395,7 +1404,7 @@ specific character position in the word.
 For prefixes, it does this by setting bit 0 if that char is valid 
 in the first position, bit 1 if valid in the second position, and so on. 
 
-If a bit is not set, then that char is not valid for that postion in the
+If a bit is not set, then that char is not valid for that position in the
 word.
 
 If working with suffixes bit 0 is used for the character closest 
