@@ -636,9 +636,10 @@ namespace aspeller {
   WordListIterator::WordListIterator(StringEnumeration * in0,
                                    const Language * lang0,
                                    OStream * log0)
-    : in(in0), lang(lang0), log(log0), val(), str(0), str_end(0), brk(), 
+    : in(in0), lang(lang0), log(log0), val(), str(0), str_end(0),
       clean_affix(lang0, log0)
   {
+    memset(brk, '\0', sizeof(brk));
   }
 
   PosibErr<void>  WordListIterator::init(Config & config)
