@@ -323,6 +323,8 @@ namespace aspeller {
 
     CasePattern case_pattern(ParmStr str) const;
 
+    CasePattern case_pattern(const char * str, unsigned size) const;
+
     void fix_case(CasePattern case_pattern, char * str)
     {
       if (!str[0]) return;
@@ -382,6 +384,7 @@ namespace aspeller {
     }
   };
   
+  template <typename HASH_INT = size_t>
   struct InsensitiveHash {
     // hashes a string without regards to casing or special begin
     // or end characters
@@ -389,9 +392,9 @@ namespace aspeller {
     InsensitiveHash() {}
     InsensitiveHash(const Language * l)
 	: lang(l) {}
-    size_t operator() (const char * s) const
+    HASH_INT operator() (const char * s) const
     {
-      size_t h = 0;
+      HASH_INT h = 0;
       for (;;) {
 	if (*s == 0) break;
         unsigned char c = lang->to_clean(*s++);
@@ -404,9 +407,10 @@ namespace aspeller {
   struct SensitiveCompare {
     const Language * lang;
     bool case_insensitive;
-    bool ignore_accents;    
-    bool begin;
-    bool end;
+    bool ignore_accents; // unused
+    bool begin; // if not begin we are checking the end of the word
+    bool end;   // if not end we are checking the beginning of the word
+                // if both false we are checking the middle of a word
     SensitiveCompare(const Language * l = 0) 
       : lang(l), case_insensitive(false), ignore_accents(false),
         begin(true), end(true) {}
