@@ -33,15 +33,16 @@ namespace aspeller {
   enum SpecialId {main_id, personal_id, session_id, 
                   personal_repl_id, none_id};
 
-  struct SpellerDict : public LocalDict
+  struct SpellerDict
   {
+    Dict *            dict;
     bool              use_to_check;
     bool              use_to_suggest;
     bool              save_on_saveall;
     SpecialId         special_id;
     SpellerDict     * next;
-    SpellerDict(LocalDict &);
-    SpellerDict(Dict *, const Language *, const Config &, SpecialId id = none_id);
+    SpellerDict(Dict *);
+    SpellerDict(Dict *, const Config &, SpecialId id = none_id);
     ~SpellerDict() {if (dict) dict->release();}
   };
 
@@ -71,7 +72,7 @@ namespace aspeller {
     //
     // Add a single dictionary that has not been previously added
     //
-    void add_dict(SpellerDict *);
+    PosibErr<void> add_dict(SpellerDict *);
 
     PosibErr<const WordList *> personal_word_list  () const;
     PosibErr<const WordList *> session_word_list   () const;
@@ -92,13 +93,13 @@ namespace aspeller {
     //
   
     PosibErr<bool> check(char * word, char * word_end, /* it WILL modify word */
-			 unsigned int run_together_limit,
+                         bool try_uppercase,
+			 unsigned run_together_limit,
 			 CheckInfo *, GuessInfo *);
 
     PosibErr<bool> check(MutableString word) {
-      guess_info.reset(guesses);
-      return check(word.begin(), 
-		   word.end(), 
+      guess_info.reset();
+      return check(word.begin(), word.end(), false,
 		   unconditional_run_together_ ? run_together_limit_ : 0,
 		   check_inf, &guess_info);
     }
@@ -111,6 +112,10 @@ namespace aspeller {
 
     PosibErr<bool> check(const char * word) {return check(ParmString(word));}
 
+    bool check2(char * word, /* it WILL modify word */
+                bool try_uppercase,
+                CheckInfo & ci, GuessInfo * gi);
+
     bool check_affix(ParmString word, CheckInfo & ci, GuessInfo * gi);
 
     bool check_simple(ParmString, WordEntry &);
@@ -118,8 +123,8 @@ namespace aspeller {
     const CheckInfo * check_info() {
       if (check_inf[0].word)
         return check_inf;
-      else if (guess_info.num > 0)
-        return guesses + 1;
+      else if (guess_info.head)
+        return guess_info.head;
       else
         return 0;
     }
@@ -162,11 +167,6 @@ namespace aspeller {
     ClonePtr<Suggest>       intr_suggest_;
     unsigned int            ignore_count;
     bool                    ignore_repl;
-    bool                    unconditional_run_together_;
-    unsigned int            run_together_limit_;
-    const char *            run_together_middle_;
-    unsigned int            run_together_min_;
-    unsigned int            run_together_start_len_;
     String                  prev_mis_repl_;
     String                  prev_cor_repl_;
 
@@ -194,43 +194,61 @@ namespace aspeller {
 		     const char *, const char *) const;
 
     CheckInfo check_inf[8];
-    CheckInfo guesses[8];
     GuessInfo guess_info;
 
-    struct WSInfo : public LocalDictInfo
-    {
-      const Dictionary * dict;
-    };
+    SensitiveCompare s_cmp;
+    SensitiveCompare s_cmp_begin;  // These (s_cmp_begin,middle,end)
+    SensitiveCompare s_cmp_middle; // are used by the affix code.
+    SensitiveCompare s_cmp_end;
 
-    typedef Vector<WSInfo> WS;
+    typedef Vector<const Dict *> WS;
     WS check_ws, affix_ws, suggest_ws, suggest_affix_ws;
 
+    bool                    unconditional_run_together_;
+    unsigned int            run_together_limit_;
+    unsigned int            run_together_min_;
+
     bool affix_info, affix_compress;
 
-    bool use_soundslike, fast_scan, fast_lookup;
+    bool have_repl;
+
+    bool have_soundslike;
+
+    bool invisible_soundslike, soundslike_root_only;
+
+    bool fast_scan, fast_lookup;
+
+    bool run_together;
 
   };
 
   struct LookupInfo {
     SpellerImpl * sp;
-    enum Mode {Word, Guess, Soundslike, AlwaysTrue} mode;
+    enum Mode {Word, Guess, Clean, Soundslike, AlwaysTrue} mode;
     SpellerImpl::WS::const_iterator begin;
     SpellerImpl::WS::const_iterator end;
     inline LookupInfo(SpellerImpl * s, Mode m);
-    inline bool lookup (ParmString word, WordEntry & o) const;
+    // returns 0 if nothing found
+    // 1 if a match is found
+    // -1 if a word is found but affix doesn't match and "gi"
+    int lookup (ParmString word, const SensitiveCompare * c, char aff, 
+                WordEntry & o, GuessInfo * gi) const;
   };
 
-  inline LookupInfo::LookupInfo(SpellerImpl * s, Mode m) : sp(s), mode(m) {
+  inline LookupInfo::LookupInfo(SpellerImpl * s, Mode m) 
+    : sp(s), mode(m) 
+  {
     switch (m) { 
     case Word: 
       begin = sp->affix_ws.begin(); 
       end = sp->affix_ws.end();
       return;
-    case Guess: 
+    case Guess:
       begin = sp->check_ws.begin(); 
       end = sp->check_ws.end(); 
       mode = Word; 
       return;
+    case Clean:
     case Soundslike: 
       begin = sp->suggest_affix_ws.begin(); 
       end = sp->suggest_affix_ws.end(); 
