@@ -82,7 +82,7 @@ namespace {
   }
   
   //
-  // OriginalWord stores infomation about the original misspelled word
+  // OriginalWord stores information about the original misspelled word
   //   for convince and speed.
   //
   struct OriginalWord {
@@ -380,7 +380,7 @@ namespace {
 
   // Forms a word by combining CheckInfo fields.
   // Will grow the grow the temp in the buffer.  The final
-  // word must be null terminated and commited.
+  // word must be null terminated and committed.
   // It returns a MutableString of what was appended to the buffer.
   MutableString Working::form_word(CheckInfo & ci) 
   {
@@ -409,7 +409,7 @@ namespace {
         add_nearmiss(i, sw, 0, score, -1, do_count);
     }
     if (sp->affix_compress) {
-      CheckInfo ci; memset(&ci, 0, sizeof(ci));
+      CheckInfo ci; memset(static_cast<void *>(&ci), 0, sizeof(ci));
       bool res = lang->affix()->affix_check(LookupInfo(sp, LookupInfo::Clean), str, ci, 0);
       if (!res) return;
       form_word(ci);
@@ -459,7 +459,7 @@ namespace {
       res = check_word(i, word_end, ci + 1, pos + 1);
       if (res) return res;
     }
-    memset(ci, 0, sizeof(CheckInfo));
+    memset(static_cast<void *>(ci), 0, sizeof(CheckInfo));
     return 0;
   }
 
@@ -478,7 +478,7 @@ namespace {
         t[0] = lang->to_lower(t[0]);
     }
     char * end = (char *)buffer.grow_temp(1);
-    char * beg = (char *)buffer.temp_ptr(); // since the orignal string may of moved
+    char * beg = (char *)buffer.temp_ptr(); // since the original string may of moved
     *end = 0;
     buffer.commit_temp();
     add_nearmiss(beg, end - beg, 0, 0, score, -1, do_count);
@@ -615,7 +615,7 @@ namespace {
     
     // Interchange two adjacent letters.
     
-    for (i = 0; i+1 != orig.size(); ++i) {
+    for (i = 0; i+1 < orig.size(); ++i) {
       a = new_word[i];
       b = new_word[i+1];
       new_word[i] = b;
@@ -1368,7 +1368,8 @@ namespace aspeller {
     ngram_keep = 10;
     use_typo_analysis = true;
     use_repl_table = sp->have_repl;
-    try_one_edit_word = sp->soundslike_root_only || sp->unconditional_run_together_;
+    try_one_edit_word = true; // always a good idea, even when
+                              // soundslike lookup is used
     check_after_one_edit_word = false;
     ngram_threshold = 2;
     if (mode == "ultra") {
@@ -1402,10 +1403,9 @@ namespace aspeller {
       return make_err(bad_value, "sug-mode", mode, _("one of ultra, fast, normal, slow, or bad-spellers"));
     }
     if (!sp->have_soundslike) {
-      if (try_scan_2) {
-        try_scan_1 = false;
-      } else if (try_scan_1) {
-        try_one_edit_word = true;
+      // in this case try_scan_1 will not get better results than
+      // try_one_edit_word
+      if (try_scan_1) {
         check_after_one_edit_word = true;
         try_scan_1 = false;
       }
