@@ -1,3 +1,9 @@
+// This file is part of The New Aspell
+// Copyright (C) 2000,2011 by Kevin Atkinson under the GNU LGPL
+// license version 2.0 or 2.1.  You should have received a copy of the
+// LGPL license along with this library if you did not you can find it
+// at http://www.gnu.org/.
+
 #include <time.h>
 
 #include "hash-t.hpp"
@@ -25,7 +31,7 @@ typedef const char * Str;
 typedef unsigned char byte;
 
 struct Hash {
-  InsensitiveHash f;
+  InsensitiveHash<> f;
   Hash(const Language * l) : f(l) {}
   size_t operator() (Str s) const {
     return f(s);
@@ -40,9 +46,51 @@ struct Equal {
   }
 };
 
+void write_n_escape(FStream & o, const char * str) {
+  while (*str != '\0') {
+    if (*str == '\n') o << "\\n";
+    else if (*str == '\r') o << "\\r";
+    else if (*str == '\\') o << "\\\\";
+    else o << *str;
+    ++str;
+  }
+}
+
+static inline char f_getc(FStream & in) {
+  int c = in.get();
+  return c == EOF ? '\0' : (char)c;
+}
+  
+bool getline_n_unescape(FStream & in, String & str, char delem) {
+  str.clear();
+  char c = f_getc(in);
+  if (!c) return false;
+  while (c && c != delem) {
+    if (c == '\\') {
+      c = f_getc(in);
+      if (c == 'n') str.append('\n');
+      else if (c == 'r') str.append('\r');
+      else if (c == '\\') str.append('\\');
+      else {str.append('\\'); continue;}
+    } else {
+      str.append(c);
+    }
+    c = f_getc(in);
+  }
+  return true;
+}
+
+bool getline_n_unescape(FStream & in, DataPair & d, String & buf)
+{
+  if (!getline_n_unescape(in, buf, '\n')) return false;
+  d.value.str  = buf.mstr();
+  d.value.size = buf.size();
+  return true;
+}
+
 typedef Vector<Str> StrVector;
 
-typedef hash_set<Str,Hash,Equal> WordLookup;
+typedef hash_multiset<Str,Hash,Equal> WordLookup;
 typedef hash_map<Str,StrVector>  SoundslikeLookup;
 
 class WritableBase : public Dictionary {
@@ -51,7 +99,7 @@ protected:
   String compatibility_suffix;
     
   time_t cur_file_date;
-    
+  
   String compatibility_file_name;
     
   WritableBase(BasicType t, const char * n, const char * s, const char * cs)
@@ -70,6 +118,7 @@ protected:
   PosibErr<void> load(ParmString, Config &, DictList *, SpellerImpl *);
   PosibErr<void> merge(ParmString);
   PosibErr<void> save_as(ParmString);
+  PosibErr<void> clear();
 
   String file_encoding;
   ConvObj iconv;
@@ -195,6 +244,13 @@ PosibErr<void> WritableBase::save(bool do_update) {
   return no_err;
 }
 
+PosibErr<void> WritableBase::clear() {
+  word_lookup->clear();
+  soundslike_lookup_.clear();
+  buffer.reset();
+  return no_err;
+}
+
 PosibErr<void> WritableBase::set_file_encoding(ParmString enc, Config & c)
 {
   if (enc == file_encoding) return no_err;
@@ -337,7 +393,7 @@ public:
 
   bool lookup(ParmString word, const SensitiveCompare *, WordEntry &) const;
 
-  bool clean_lookup(const char * sondslike, WordEntry &) const;
+  bool clean_lookup(ParmString sondslike, WordEntry &) const;
 
   bool soundslike_lookup(const WordEntry & soundslike, WordEntry &) const;
   bool soundslike_lookup(ParmString soundslike, WordEntry &) const;
@@ -373,7 +429,7 @@ bool WritableDict::lookup(ParmString word, const SensitiveCompare * c,
   return false;
 }
 
-bool WritableDict::clean_lookup(const char * sl, WordEntry & o) const
+bool WritableDict::clean_lookup(ParmString sl, WordEntry & o) const
 {
   o.clear();
   pair<WordLookup::iterator, WordLookup::iterator> p(word_lookup->equal_range(sl));
@@ -500,7 +556,7 @@ PosibErr<void> WritableDict::merge(FStream & in,
     set_file_encoding("", *config);
   
   ConvP conv(iconv);
-  while (getline(in, dp, buf)) {
+  while (getline_n_unescape(in, dp, buf)) {
     if (ver == 10)
       split(dp);
     else
@@ -524,7 +580,8 @@ PosibErr<void> WritableDict::save(FStream & out, ParmString file_name)
     
   ConvP conv(oconv);
   for (;i != e; ++i) {
-    out.printf("%s\n", conv(*i));
+    write_n_escape(out, conv(*i));
+    out << '\n';
   }
   return no_err;
 }
@@ -771,7 +828,10 @@ PosibErr<void> WritableReplDict::save (FStream & out, ParmString file_name)
     StrVector * v = get_vector(*i);
     for (StrVector::iterator j = v->begin(); j != v->end(); ++j)
     {
-      out.printf("%s %s\n", conv1(*i), conv2(*j));
+      write_n_escape(out, conv1(*i));
+      out << ' ';
+      write_n_escape(out, conv2(*j));
+      out << '\n';
     }
   }
   return no_err;
@@ -783,7 +843,6 @@ PosibErr<void> WritableReplDict::merge(FStream & in,
 {
   typedef PosibErr<void> Ret;
   unsigned int version;
-  String word, mis, sound, repl;
   unsigned int num_words, num_repls;
 
   String buf;
@@ -825,16 +884,21 @@ PosibErr<void> WritableReplDict::merge(FStream & in,
 
     ConvP conv1(iconv);
     ConvP conv2(iconv);
-    do {
-      in.getline(mis, ' ');
-      if (!in) break;
-      in.getline(repl, '\n');
-      if (!in) make_err(bad_file_format, file_name);
+    for (;;) {
+      bool res = getline_n_unescape(in, buf, '\n');
+      if (!res) break;
+      char * mis = buf.mstr();
+      char * repl = strchr(mis, ' ');
+      if (!repl) continue; // bad line, ignore
+      *repl = '\0'; // split string
+      ++repl;
+      if (!repl[0]) continue; // empty repl, ignore
       WritableReplDict::add_repl(conv1(mis), conv2(repl));
-    } while (true);
-
+    }
+    
   } else {
-
+    
+    String mis, sound, repl;
     unsigned int h,i,j;
     for (h=0; h != num_soundslikes; ++h) {
       in >> sound >> num_words;
