@@ -1,8 +1,8 @@
-// This file is part of The New Aspell
-// Copyright (C) 2002,2003,2004 by Kevin Atkinson under the GNU LGPL license
+// This file is part of The New Aspell Copyright (C)
+// 2002,2003,2004,2011 by Kevin Atkinson under the GNU LGPL license
 // version 2.0 or 2.1.  You should have received a copy of the LGPL
-// license along with this library if you did not you can find
-// it at http://www.gnu.org/.
+// license along with this library if you did not you can find it at
+// http://www.gnu.org/.
 
 //
 // NOTE: This program currently uses a very ugly mix of the internal
@@ -239,6 +239,14 @@ static const PossibleOption * find_option(const char * str) {
   return i;
 }
 
+static void line_buffer() {
+#ifndef WIN32
+  // set up stdin and stdout to be line buffered
+  assert(setvbuf(stdin, 0, _IOLBF, 0) == 0); 
+  assert(setvbuf(stdout, 0, _IOLBF, 0) == 0);
+#endif
+}
+
 Conv dconv;
 Conv uiconv;
 
@@ -653,7 +661,9 @@ void print_elements(const AspellWordList * wl) {
 struct StatusFunInf 
 {
   aspeller::SpellerImpl * real_speller;
+  Conv oconv;
   bool verbose;
+  StatusFunInf(Convert * c) : oconv(c) {}
 };
 
 void status_fun(void * d, Token, int correct)
@@ -664,7 +674,7 @@ void status_fun(void * d, Token, int correct)
     if (ci->compound)
       COUT.put("-\n");
     else if (ci->pre_flag || ci->suf_flag)
-      COUT.printf("+ %s\n", ci->word.str());
+      COUT.printf("+ %s\n", p->oconv(ci->word.str()));
     else
       COUT.put("*\n");
   }
@@ -686,11 +696,7 @@ DocumentChecker * new_checker(AspellSpeller * speller,
 
 void pipe() 
 {
-#ifndef WIN32
-  // set up stdin and stdout to be line buffered
-  assert(setvbuf(stdin, 0, _IOLBF, 0) == 0); 
-  assert(setvbuf(stdout, 0, _IOLBF, 0) == 0);
-#endif
+  line_buffer();
 
   bool terse_mode = true;
   bool do_time = options->retrieve_bool("time");
@@ -724,7 +730,7 @@ void pipe()
   if (do_time)
     COUT << _("Time to load word list: ")
          << (clock() - start)/(double)CLOCKS_PER_SEC << "\n";
-  StatusFunInf status_fun_inf;
+  StatusFunInf status_fun_inf(setup_conv(&real_speller->lang(), config));
   status_fun_inf.real_speller = real_speller;
   bool & print_star = status_fun_inf.verbose;
   print_star = true;
@@ -870,7 +876,8 @@ void pipe()
           if (ci->pre_strip_len > 0) 
             guess.append('-').append(ci->word.str(), ci->pre_strip_len);
           if (ci->suf_strip_len > 0) 
-            guess.append('-').append(ci->word.str() - ci->suf_strip_len, ci->suf_strip_len);
+            guess.append('-').append(ci->word.str() + ci->word.size() - ci->suf_strip_len, 
+                                     ci->suf_strip_len);
           if (ci->suf_add && ci->suf_add[0])
             guess.append('+').append(ci->suf_add, ci->suf_add_len);
           real_speller->lang().fix_case(casep, guess.data(), guess.data());
@@ -964,8 +971,11 @@ void check()
   if (args.size() == 0) {
     print_error(_("You must specify a file name."));
     exit(-1);
+  } else if (args.size() > 1) {
+    print_error(_("Only one file name may be specified."));
+    exit(-1);
   }
-    
+  
   file_name = args[0];
   new_name = file_name;
   new_name += ".new";
@@ -976,21 +986,6 @@ void check()
     exit(-1);
   }
     
-#ifdef USE_FILE_INO
-  {
-    struct stat st;
-    fstat(fileno(in), &st);
-    int fd = open(new_name.c_str(), O_WRONLY | O_CREAT | O_TRUNC, st.st_mode);
-    if (fd >= 0) out = fdopen(fd, "w");
-  }
-#else
-  out = fopen(new_name.c_str(), "w");
-#endif
-  if (!out) {
-    print_error(_("Could not open the file \"%s\" for writing. File not saved."), file_name);
-    exit(-1);
-  }
-
   if (!options->have("mode"))
     EXIT_ON_ERR(set_mode_from_extension(options, file_name));
     
@@ -1011,6 +1006,21 @@ void check()
     exit(1);
   }
 
+#ifdef USE_FILE_INO
+  {
+    struct stat st;
+    fstat(fileno(in), &st);
+    int fd = open(new_name.c_str(), O_WRONLY | O_CREAT | O_TRUNC, st.st_mode);
+    if (fd >= 0) out = fdopen(fd, "w");
+  }
+#else
+  out = fopen(new_name.c_str(), "w");
+#endif
+  if (!out) {
+    print_error(_("Could not open the file \"%s\" for writing. File not saved."), file_name);
+    exit(-1);
+  }
+
   setup_display_conv();
 
   AspellSpeller * speller = to_aspell_speller(ret);
@@ -1120,11 +1130,18 @@ void check()
     case Add:
       aspell_speller_add_to_personal(speller, word, -1);
       break;
-    case AddLower:
-      aspell_speller_add_to_personal
-        (speller, 
-         reinterpret_cast<Speller *>(speller)->to_lower(word), -1);
+    case AddLower: 
+    {
+      // Emulate the c function add_to_personal, but add extra step to
+      // convert word to lowercase.  Yeah its a bit of a hack.
+      Speller * sp = reinterpret_cast<Speller *>(speller);
+      sp->temp_str_0.clear();
+      sp->to_internal_->convert(word, -1, sp->temp_str_0);
+      char * lower = sp->to_lower(sp->temp_str_0.mstr());
+      PosibErr<void> ret = sp->add_to_personal(MutableString(lower));
+      sp->err_.reset(ret.release_err());
       break;
+    }
     case Replace:
     case ReplaceAll:
       // the string new_word is in the encoding of the document
@@ -1377,8 +1394,8 @@ void filter()
 //
 
 void print_ver () {
-  COUT.put("@(#) International Ispell Version 3.1.20 " 
-           "(but really Aspell " VERSION ")\n");
+  printf("@(#) International Ispell Version 3.1.20 " 
+         "(but really Aspell %s)\n", aspell_version_string());
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -1647,6 +1664,7 @@ void soundslike() {
   Conv oconv(setup_conv(lang, options));
   String word;
   String sl;
+  line_buffer();
   while (CIN.getline(word)) {
     const char * w = iconv(word);
     lang->LangImpl::to_soundslike(sl, w);
@@ -1671,6 +1689,7 @@ void munch()
   Conv oconv(setup_conv(lang, options));
   String word;
   GuessInfo gi;
+  line_buffer();
   while (CIN.getline(word)) {
     lang->munch(iconv(word), &gi);
     COUT << word;
@@ -1709,6 +1728,7 @@ void expand()
   String word, buf;
   ObjStack exp_buf;
   WordAff * exp_list;
+  line_buffer();
   while (CIN.getline(word)) {
     buf = word;
     char * w = iconv(buf.mstr(), buf.size());
@@ -1795,6 +1815,7 @@ void combine()
   String word;
   String base;
   String affs;
+  line_buffer();
   while (CIN.getline(word)) {
     word = iconv(word);
 
@@ -1878,7 +1899,7 @@ struct SML_Parms {
   typedef SML_WordEntry Value;
   typedef const char * Key;
   static const bool is_multi = false;
-  hash<const char *> hash;
+  acommon::hash<const char *> hash;
   bool equal(Key x, Key y) {return strcmp(x,y) == 0;}
   Key key(const Value & v) {return v.word;}
 };
@@ -2029,7 +2050,7 @@ struct CML_Parms {
   typedef CML_Entry Value;
   typedef const char * Key;
   static const bool is_multi = true;
-  hash<const char *> hash;
+  acommon::hash<const char *> hash;
   bool equal(Key x, Key y) {return strcmp(x,y) == 0;}
   Key key(const Value & v) {return v.word;}
 };
@@ -2522,6 +2543,9 @@ void munch_list_complete(bool multi, bool simplify)
     }
 
     to_keep_exp.resize(entries.size());
+    //for (int i = 0; i != to_keep_exp.size(); ++i) {
+    //  printf(">>> %d %d\n", i, (int)to_keep_exp[i]);
+    //}
 
     // Store the expansion of each base word in a bit vector and
     // add it to the working set
@@ -2683,6 +2707,11 @@ void munch_list_complete(bool multi, bool simplify)
 
     // Finally print the resulting list
 
+    //printf("XXX %d %d\n", to_keep.size(), to_keep_exp.size());
+    //for (int i = 0; i != to_keep_exp.size(); ++i) {
+    //  printf(">>> %d %d\n", i, (int)to_keep_exp[i]);
+    //}
+
     for (unsigned i = 0; i != to_keep.size(); ++i) {
       COUT << oconv(to_keep[i]->word);
       if (to_keep[i]->aff[0]) {
@@ -2799,7 +2828,7 @@ static const char * help_text[] =
   N_("  clean [strict]   cleans a word list so that every line is a valid word"),
   //N_("  filter           passes standard input through filters"),
   N_("  -v|version       prints a version line"),
-  N_("  munch-list [simple] [single|multi] [keep]\n")
+  N_("  munch-list [simple] [single|multi] [keep]"),
   N_("    reduce the size of a word list via affix compression"),
   N_("  conv <from> <to> [<norm-form>]"),
   N_("    converts from one encoding to another"),
@@ -2823,8 +2852,8 @@ void print_help (bool verbose) {
   load_all_filters(options);
   if (verbose) {
     printf(_("\n"
-             "Aspell %s.  Copyright 2000-2004 by Kevin Atkinson.\n"
-             "\n"), VERSION);
+             "Aspell %s.  Copyright 2000-2011 by Kevin Atkinson.\n"
+             "\n"), aspell_version_string());
     for (unsigned i = 0; i < help_text_size; ++i)
       puts(gt_(help_text[i]));
   } else {
